@@ -1,17 +1,18 @@
-#include <iostream>
-#include <string.h>
-#include <stdlib.h>
+#include <qpdf/Buffer.hh>
+#include <qpdf/QIntC.hh>
 #include <qpdf/QPDF.hh>
 #include <qpdf/QPDFPageDocumentHelper.hh>
 #include <qpdf/QPDFPageObjectHelper.hh>
-#include <qpdf/QUtil.hh>
-#include <qpdf/Buffer.hh>
 #include <qpdf/QPDFWriter.hh>
-#include <qpdf/QIntC.hh>
+#include <qpdf/QUtil.hh>
+#include <iostream>
+#include <stdlib.h>
+#include <string.h>
 
-static char const* whoami = 0;
+static char const* whoami = nullptr;
 
-void usage()
+void
+usage()
 {
     std::cerr << "Usage: " << whoami << " infile.pdf outfile.pdf [in-password]"
               << std::endl
@@ -32,15 +33,13 @@ void usage()
 class ImageInverter: public QPDFObjectHandle::StreamDataProvider
 {
   public:
-    virtual ~ImageInverter()
-    {
-    }
-    virtual void provideStreamData(int objid, int generation,
-                                   Pipeline* pipeline) override;
+    virtual ~ImageInverter() = default;
+    virtual void
+    provideStreamData(QPDFObjGen const& og, Pipeline* pipeline) override;
 
     void registerImage(
         QPDFObjectHandle image,
-        PointerHolder<QPDFObjectHandle::StreamDataProvider> self);
+        std::shared_ptr<QPDFObjectHandle::StreamDataProvider> self);
 
   private:
     std::map<QPDFObjGen, QPDFObjectHandle> copied_images;
@@ -49,14 +48,14 @@ class ImageInverter: public QPDFObjectHandle::StreamDataProvider
 void
 ImageInverter::registerImage(
     QPDFObjectHandle image,
-    PointerHolder<QPDFObjectHandle::StreamDataProvider> self)
+    std::shared_ptr<QPDFObjectHandle::StreamDataProvider> self)
 {
     // replaceStreamData requires a pointer holder to the stream data
     // provider, but there's no way for us to generate one ourselves,
     // so we have to have it handed to us. Don't be tempted to have
-    // the class contain a PointerHolder to itself as a member. Doing
+    // the class contain a std::shared_ptr to itself as a member. Doing
     // this will prevent the class from ever being deleted since the
-    // reference count will never drop to zero (and PointerHolder
+    // reference count will never drop to zero (and std::shared_ptr
     // doesn't have weak references).
 
     QPDFObjGen og(image.getObjGen());
@@ -64,8 +63,7 @@ ImageInverter::registerImage(
     // generation number. Recall that a single image object may be
     // used more than once, so no need to update the same stream
     // multiple times.
-    if (this->copied_images.count(og) > 0)
-    {
+    if (this->copied_images.count(og) > 0) {
         return;
     }
     this->copied_images[og] = image.copyStream();
@@ -79,53 +77,42 @@ ImageInverter::registerImage(
     // filterable in the input QPDF object, so we don't have to deal
     // with it explicitly here. We could explicitly use /DCTDecode and
     // write through a DCT filter if we wanted.
-    image.replaceStreamData(self,
-                            QPDFObjectHandle::newNull(),
-                            QPDFObjectHandle::newNull());
+    image.replaceStreamData(
+        self, QPDFObjectHandle::newNull(), QPDFObjectHandle::newNull());
 }
 
 void
-ImageInverter::provideStreamData(int objid, int generation,
-                                 Pipeline* pipeline)
+ImageInverter::provideStreamData(QPDFObjGen const& og, Pipeline* pipeline)
 {
     // Use the object and generation number supplied to look up the
     // image data.  Then invert the image data and write the inverted
     // data to the pipeline.
-    QPDFObjGen og(objid, generation);
-    PointerHolder<Buffer> data =
+    std::shared_ptr<Buffer> data =
         this->copied_images[og].getStreamData(qpdf_dl_all);
     size_t size = data->getSize();
     unsigned char* buf = data->getBuffer();
     unsigned char ch;
-    for (size_t i = 0; i < size; ++i)
-    {
+    for (size_t i = 0; i < size; ++i) {
         ch = QIntC::to_uchar(0xff - buf[i]);
         pipeline->write(&ch, 1);
     }
     pipeline->finish();
 }
 
-int main(int argc, char* argv[])
+int
+main(int argc, char* argv[])
 {
     whoami = QUtil::getWhoami(argv[0]);
 
-    // For libtool's sake....
-    if (strncmp(whoami, "lt-", 3) == 0)
-    {
-        whoami += 3;
-    }
-
     // For test suite
     bool static_id = false;
-    if ((argc > 1) && (strcmp(argv[1], " --static-id") == 0))
-    {
+    if ((argc > 1) && (strcmp(argv[1], " --static-id") == 0)) {
         static_id = true;
         --argc;
         ++argv;
     }
 
-    if (! ((argc == 3) || (argc == 4)))
-    {
+    if (!((argc == 3) || (argc == 4))) {
         usage();
     }
 
@@ -133,30 +120,20 @@ int main(int argc, char* argv[])
     char const* outfilename = argv[2];
     char const* password = (argc == 4) ? argv[3] : "";
 
-    try
-    {
+    try {
         QPDF qpdf;
         qpdf.processFile(infilename, password);
 
         ImageInverter* inv = new ImageInverter;
-        auto p = PointerHolder<QPDFObjectHandle::StreamDataProvider>(inv);
+        auto p = std::shared_ptr<QPDFObjectHandle::StreamDataProvider>(inv);
 
         // For each page...
-        std::vector<QPDFPageObjectHelper> pages =
-            QPDFPageDocumentHelper(qpdf).getAllPages();
-        for (std::vector<QPDFPageObjectHelper>::iterator iter = pages.begin();
-             iter != pages.end(); ++iter)
-        {
-            QPDFPageObjectHelper& page(*iter);
+        for (auto& page: QPDFPageDocumentHelper(qpdf).getAllPages()) {
             // Get all images on the page.
-            std::map<std::string, QPDFObjectHandle> images =
-                page.getImages();
-            for (auto& iter2: images)
-            {
-                QPDFObjectHandle& image = iter2.second;
+            for (auto& iter: page.getImages()) {
+                QPDFObjectHandle& image = iter.second;
                 QPDFObjectHandle image_dict = image.getDict();
-                QPDFObjectHandle color_space =
-                    image_dict.getKey("/ColorSpace");
+                QPDFObjectHandle color_space = image_dict.getKey("/ColorSpace");
                 QPDFObjectHandle bits_per_component =
                     image_dict.getKey("/BitsPerComponent");
 
@@ -165,12 +142,11 @@ int main(int argc, char* argv[])
                 // pipeStreamData with a null pipeline to determine
                 // whether the image is filterable.  Directly inspect
                 // keys to determine the image type.
-                if (image.pipeStreamData(0, qpdf_ef_compress,
-                                         qpdf_dl_all) &&
+                if (image.pipeStreamData(
+                        nullptr, qpdf_ef_compress, qpdf_dl_all) &&
                     color_space.isNameAndEquals("/DeviceGray") &&
                     bits_per_component.isInteger() &&
-                    (bits_per_component.getIntValue() == 8))
-                {
+                    (bits_per_component.getIntValue() == 8)) {
                     inv->registerImage(image, p);
                 }
             }
@@ -178,8 +154,7 @@ int main(int argc, char* argv[])
 
         // Write out a new file
         QPDFWriter w(qpdf, outfilename);
-        if (static_id)
-        {
+        if (static_id) {
             // For the test suite, uncompress streams and use static
             // IDs.
             w.setStaticID(true); // for testing only
@@ -187,9 +162,7 @@ int main(int argc, char* argv[])
         w.write();
         std::cout << whoami << ": new file written to " << outfilename
                   << std::endl;
-    }
-    catch (std::exception &e)
-    {
+    } catch (std::exception& e) {
         std::cerr << whoami << " processing file " << infilename << ": "
                   << e.what() << std::endl;
         exit(2);
