@@ -1,19 +1,20 @@
 #include <iostream>
-#include <string.h>
 #include <stdlib.h>
+#include <string.h>
 
+#include <qpdf/QIntC.hh>
 #include <qpdf/QPDF.hh>
 #include <qpdf/QPDFPageDocumentHelper.hh>
 #include <qpdf/QPDFPageObjectHelper.hh>
 #include <qpdf/QUtil.hh>
-#include <qpdf/QIntC.hh>
 
-static char const* whoami = 0;
+static char const* whoami = nullptr;
 
-void usage()
+void
+usage()
 {
     std::cerr << "Usage: " << whoami << " filename page-number" << std::endl
-	      << "Prints a dump of the objects in the content streams"
+              << "Prints a dump of the objects in the content streams"
               << " of the given page." << std::endl
               << "Pages are numbered from 1." << std::endl;
     exit(2);
@@ -22,10 +23,7 @@ void usage()
 class ParserCallbacks: public QPDFObjectHandle::ParserCallbacks
 {
   public:
-    virtual ~ParserCallbacks()
-    {
-    }
-
+    virtual ~ParserCallbacks() = default;
     virtual void contentSize(size_t);
     virtual void handleObject(QPDFObjectHandle, size_t offset, size_t length);
     virtual void handleEOF();
@@ -38,17 +36,14 @@ ParserCallbacks::contentSize(size_t size)
 }
 
 void
-ParserCallbacks::handleObject(QPDFObjectHandle obj,
-                              size_t offset, size_t length)
+ParserCallbacks::handleObject(
+    QPDFObjectHandle obj, size_t offset, size_t length)
 {
     std::cout << obj.getTypeName() << ", offset=" << offset
               << ", length=" << length << ": ";
-    if (obj.isInlineImage())
-    {
+    if (obj.isInlineImage()) {
         std::cout << QUtil::hex_encode(obj.getInlineImageValue()) << std::endl;
-    }
-    else
-    {
+    } else {
         std::cout << obj.unparse() << std::endl;
     }
 }
@@ -59,42 +54,32 @@ ParserCallbacks::handleEOF()
     std::cout << "-EOF-" << std::endl;
 }
 
-int main(int argc, char* argv[])
+int
+main(int argc, char* argv[])
 {
     whoami = QUtil::getWhoami(argv[0]);
 
-    // For libtool's sake....
-    if (strncmp(whoami, "lt-", 3) == 0)
-    {
-	whoami += 3;
-    }
-
-    if (argc != 3)
-    {
-	usage();
+    if (argc != 3) {
+        usage();
     }
     char const* filename = argv[1];
     int pageno = QUtil::string_to_int(argv[2]);
 
-    try
-    {
-	QPDF pdf;
-	pdf.processFile(filename);
+    try {
+        QPDF pdf;
+        pdf.processFile(filename);
         std::vector<QPDFPageObjectHelper> pages =
             QPDFPageDocumentHelper(pdf).getAllPages();
-        if ((pageno < 1) || (QIntC::to_size(pageno) > pages.size()))
-        {
+        if ((pageno < 1) || (QIntC::to_size(pageno) > pages.size())) {
             usage();
         }
 
-        QPDFPageObjectHelper& page = pages.at(QIntC::to_size(pageno-1));
+        QPDFPageObjectHelper& page = pages.at(QIntC::to_size(pageno - 1));
         ParserCallbacks cb;
-        page.parsePageContents(&cb);
-    }
-    catch (std::exception& e)
-    {
-	std::cerr << whoami << ": " << e.what() << std::endl;
-	exit(2);
+        page.parseContents(&cb);
+    } catch (std::exception& e) {
+        std::cerr << whoami << ": " << e.what() << std::endl;
+        exit(2);
     }
 
     return 0;
