@@ -1,7 +1,7 @@
 #include <qpdf/InsecureRandomDataProvider.hh>
 
-#include <qpdf/qpdf-config.h>
 #include <qpdf/QUtil.hh>
+#include <qpdf/qpdf-config.h>
 #include <stdlib.h>
 
 InsecureRandomDataProvider::InsecureRandomDataProvider() :
@@ -9,15 +9,10 @@ InsecureRandomDataProvider::InsecureRandomDataProvider() :
 {
 }
 
-InsecureRandomDataProvider::~InsecureRandomDataProvider()
-{
-}
-
 void
 InsecureRandomDataProvider::provideRandomData(unsigned char* data, size_t len)
 {
-    for (size_t i = 0; i < len; ++i)
-    {
+    for (size_t i = 0; i < len; ++i) {
         data[i] = static_cast<unsigned char>((this->random() & 0xff0) >> 4);
     }
 }
@@ -25,13 +20,12 @@ InsecureRandomDataProvider::provideRandomData(unsigned char* data, size_t len)
 long
 InsecureRandomDataProvider::random()
 {
-    if (! this->seeded_random)
-    {
+    if (!this->seeded_random) {
         // Seed the random number generator with something simple, but
         // just to be interesting, don't use the unmodified current
         // time.  It would be better if this were a more secure seed.
-        unsigned int seed = static_cast<unsigned int>(
-            QUtil::get_current_time() ^ 0xcccc);
+        unsigned int seed =
+            static_cast<unsigned int>(QUtil::get_current_time() ^ 0xcccc);
 #ifdef HAVE_RANDOM
         ::srandom(seed);
 #else
@@ -40,11 +34,11 @@ InsecureRandomDataProvider::random()
         this->seeded_random = true;
     }
 
-#  ifdef HAVE_RANDOM
+#ifdef HAVE_RANDOM
     return ::random();
-#  else
+#else
     return rand();
-#  endif
+#endif
 }
 
 RandomDataProvider*
