@@ -1,9 +1,9 @@
 #include <qpdf/Pl_ASCIIHexDecoder.hh>
 
 #include <qpdf/QTC.hh>
+#include <ctype.h>
 #include <stdexcept>
 #include <string.h>
-#include <ctype.h>
 
 Pl_ASCIIHexDecoder::Pl_ASCIIHexDecoder(char const* identifier, Pipeline* next) :
     Pipeline(identifier, next),
@@ -15,60 +15,48 @@ Pl_ASCIIHexDecoder::Pl_ASCIIHexDecoder(char const* identifier, Pipeline* next) :
     this->inbuf[2] = '\0';
 }
 
-Pl_ASCIIHexDecoder::~Pl_ASCIIHexDecoder()
-{
-}
-
 void
-Pl_ASCIIHexDecoder::write(unsigned char* buf, size_t len)
+Pl_ASCIIHexDecoder::write(unsigned char const* buf, size_t len)
 {
-    if (this->eod)
-    {
+    if (this->eod) {
         return;
     }
-    for (size_t i = 0; i < len; ++i)
-    {
+    for (size_t i = 0; i < len; ++i) {
         char ch = static_cast<char>(toupper(buf[i]));
-        switch (ch)
-        {
-          case ' ':
-          case '\f':
-          case '\v':
-          case '\t':
-          case '\r':
-          case '\n':
+        switch (ch) {
+        case ' ':
+        case '\f':
+        case '\v':
+        case '\t':
+        case '\r':
+        case '\n':
             QTC::TC("libtests", "Pl_ASCIIHexDecoder ignore space");
             // ignore whitespace
             break;
 
-          case '>':
+        case '>':
             this->eod = true;
             flush();
             break;
 
-          default:
-            if (((ch >= '0') && (ch <= '9')) ||
-                ((ch >= 'A') && (ch <= 'F')))
-            {
+        default:
+            if (((ch >= '0') && (ch <= '9')) || ((ch >= 'A') && (ch <= 'F'))) {
                 this->inbuf[this->pos++] = ch;
-                if (this->pos == 2)
-                {
+                if (this->pos == 2) {
                     flush();
                 }
-            }
-            else
-            {
+            } else {
                 char t[2];
                 t[0] = ch;
                 t[1] = 0;
                 throw std::runtime_error(
                     std::string("character out of range"
-                                " during base Hex decode: ") + t);
+                                " during base Hex decode: ") +
+                    t);
             }
             break;
         }
-        if (this->eod)
-        {
+        if (this->eod) {
             break;
         }
     }
@@ -77,27 +65,24 @@ Pl_ASCIIHexDecoder::write(unsigned char* buf, size_t len)
 void
 Pl_ASCIIHexDecoder::flush()
 {
-    if (this->pos == 0)
-    {
+    if (this->pos == 0) {
         QTC::TC("libtests", "Pl_ASCIIHexDecoder no-op flush");
         return;
     }
     int b[2];
-    for (int i = 0; i < 2; ++i)
-    {
-        if (this->inbuf[i] >= 'A')
-        {
+    for (int i = 0; i < 2; ++i) {
+        if (this->inbuf[i] >= 'A') {
             b[i] = this->inbuf[i] - 'A' + 10;
-        }
-        else
-        {
+        } else {
             b[i] = this->inbuf[i] - '0';
         }
     }
     unsigned char ch = static_cast<unsigned char>((b[0] << 4) + b[1]);
 
-    QTC::TC("libtests", "Pl_ASCIIHexDecoder partial flush",
-            (this->pos == 2) ? 0 : 1);
+    QTC::TC(
+        "libtests",
+        "Pl_ASCIIHexDecoder partial flush",
+        (this->pos == 2) ? 0 : 1);
     // Reset before calling getNext()->write in case that throws an
     // exception.
     this->pos = 0;
