@@ -1,4 +1,5 @@
 #include <qpdf/Pl_Count.hh>
+
 #include <qpdf/QIntC.hh>
 
 Pl_Count::Members::Members() :
@@ -7,10 +8,6 @@ Pl_Count::Members::Members() :
 {
 }
 
-Pl_Count::Members::~Members()
-{
-}
-
 Pl_Count::Pl_Count(char const* identifier, Pipeline* next) :
     Pipeline(identifier, next),
     m(new Members())
@@ -19,16 +16,17 @@ Pl_Count::Pl_Count(char const* identifier, Pipeline* next) :
 
 Pl_Count::~Pl_Count()
 {
+    // Must be explicit and not inline -- see QPDF_DLL_CLASS in
+    // README-maintainer
 }
 
 void
-Pl_Count::write(unsigned char* buf, size_t len)
+Pl_Count::write(unsigned char const* buf, size_t len)
 {
-    if (len)
-    {
-	this->m->count += QIntC::to_offset(len);
-	this->m->last_char = buf[len - 1];
-	getNext()->write(buf, len);
+    if (len) {
+        this->m->count += QIntC::to_offset(len);
+        this->m->last_char = buf[len - 1];
+        getNext()->write(buf, len);
     }
 }
 
