@@ -2,25 +2,19 @@
 
 // Exercised in md5 test suite
 
-Pl_Discard::Members::Members()
-{
-}
-
-Pl_Discard::Members::~Members()
-{
-}
-
 Pl_Discard::Pl_Discard() :
-    Pipeline("discard", 0)
+    Pipeline("discard", nullptr)
 {
 }
 
 Pl_Discard::~Pl_Discard()
 {
+    // Must be explicit and not inline -- see QPDF_DLL_CLASS in
+    // README-maintainer
 }
 
 void
-Pl_Discard::write(unsigned char* buf, size_t len)
+Pl_Discard::write(unsigned char const* buf, size_t len)
 {
 }
 
