@@ -2,35 +2,32 @@
 
 #include <qpdf/QUtil.hh>
 
-Pl_RC4::Pl_RC4(char const* identifier, Pipeline* next,
-               unsigned char const* key_data, int key_len,
-               size_t out_bufsize) :
+Pl_RC4::Pl_RC4(
+    char const* identifier,
+    Pipeline* next,
+    unsigned char const* key_data,
+    int key_len,
+    size_t out_bufsize) :
     Pipeline(identifier, next),
     out_bufsize(out_bufsize),
     rc4(key_data, key_len)
 {
-    this->outbuf = make_array_pointer_holder<unsigned char>(out_bufsize);
-}
-
-Pl_RC4::~Pl_RC4()
-{
+    this->outbuf = QUtil::make_shared_array<unsigned char>(out_bufsize);
 }
 
 void
-Pl_RC4::write(unsigned char* data, size_t len)
+Pl_RC4::write(unsigned char const* data, size_t len)
 {
-    if (this->outbuf.get() == 0)
-    {
+    if (this->outbuf == nullptr) {
         throw std::logic_error(
             this->identifier +
             ": Pl_RC4: write() called after finish() called");
     }
 
     size_t bytes_left = len;
-    unsigned char* p = data;
+    unsigned char const* p = data;
 
-    while (bytes_left > 0)
-    {
+    while (bytes_left > 0) {
         size_t bytes =
             (bytes_left < this->out_bufsize ? bytes_left : out_bufsize);
         bytes_left -= bytes;
@@ -44,6 +41,6 @@ Pl_RC4::write(unsigned char* data, size_t len)
 void
 Pl_RC4::finish()
 {
-    this->outbuf = 0;
+    this->outbuf = nullptr;
     this->getNext()->finish();
 }
