@@ -517,6 +517,13 @@ QPDFJob::Config::requiresPassword()
     return this;
 }
 
+QPDFJob::Config*
+QPDFJob::Config::removeRestrictions()
+{
+    o.m->remove_restrictions = true;
+    return this;
+}
+
 QPDFJob::Config*
 QPDFJob::Config::showAttachment(std::string const& parameter)
 {
