@@ -1,6 +1,7 @@
 #include <qpdf/QPDF_Array.hh>
 
 #include <qpdf/QIntC.hh>
+#include <qpdf/QPDFObject_private.hh>
 #include <qpdf/QUtil.hh>
 #include <stdexcept>
 
@@ -10,6 +11,12 @@ QPDF_Array::QPDF_Array(std::vector<QPDFObjectHandle> const& v) :
     setFromVector(v);
 }
 
+QPDF_Array::QPDF_Array(std::vector<std::shared_ptr<QPDFObject>>&& v) :
+    QPDFValue(::ot_array, "array")
+{
+    setFromVector(std::move(v));
+}
+
 QPDF_Array::QPDF_Array(SparseOHArray const& items) :
     QPDFValue(::ot_array, "array"),
     elements(items)
@@ -22,6 +29,12 @@ QPDF_Array::create(std::vector<QPDFObjectHandle> const& items)
     return do_create(new QPDF_Array(items));
 }
 
+std::shared_ptr<QPDFObject>
+QPDF_Array::create(std::vector<std::shared_ptr<QPDFObject>>&& items)
+{
+    return do_create(new QPDF_Array(std::move(items)));
+}
+
 std::shared_ptr<QPDFObject>
 QPDF_Array::create(SparseOHArray const& items)
 {
@@ -29,9 +42,9 @@ QPDF_Array::create(SparseOHArray const& items)
 }
 
 std::shared_ptr<QPDFObject>
-QPDF_Array::shallowCopy()
+QPDF_Array::copy(bool shallow)
 {
-    return create(elements);
+    return create(shallow ? elements : elements.copy());
 }
 
 void
@@ -106,6 +119,19 @@ QPDF_Array::setFromVector(std::vector<QPDFObjectHandle> const& v)
     }
 }
 
+void
+QPDF_Array::setFromVector(std::vector<std::shared_ptr<QPDFObject>>&& v)
+{
+    this->elements = SparseOHArray();
+    for (auto&& item: v) {
+        if (item) {
+            this->elements.append(item);
+        } else {
+            ++this->elements.n_elements;
+        }
+    }
+}
+
 void
 QPDF_Array::insertItem(int at, QPDFObjectHandle const& item)
 {
