@@ -173,12 +173,6 @@ QPDF_String::unparse(bool force_binary)
     return result;
 }
 
-std::string
-QPDF_String::getVal() const
-{
-    return this->val;
-}
-
 std::string
 QPDF_String::getUTF8Val() const
 {
