@@ -4,6 +4,9 @@
 #include <qpdf/Pl_Base64.hh>
 #include <qpdf/Pl_StdioFile.hh>
 #include <qpdf/QIntC.hh>
+#include <qpdf/QPDFObject_private.hh>
+#include <qpdf/QPDFValue.hh>
+#include <qpdf/QPDF_Null.hh>
 #include <qpdf/QTC.hh>
 #include <qpdf/QUtil.hh>
 #include <algorithm>
@@ -221,30 +224,83 @@ provide_data(
     };
 }
 
-QPDF::JSONReactor::JSONReactor(
-    QPDF& pdf, std::shared_ptr<InputSource> is, bool must_be_complete) :
-    pdf(pdf),
-    is(is),
-    must_be_complete(must_be_complete),
-    errors(false),
-    parse_error(false),
-    saw_qpdf(false),
-    saw_qpdf_meta(false),
-    saw_objects(false),
-    saw_json_version(false),
-    saw_pdf_version(false),
-    saw_trailer(false),
-    state(st_initial),
-    next_state(st_top),
-    saw_value(false),
-    saw_stream(false),
-    saw_dict(false),
-    saw_data(false),
-    saw_datafile(false),
-    this_stream_needs_data(false)
+class QPDF::JSONReactor: public JSON::Reactor
 {
-    state_stack.push_back(st_initial);
-}
+  public:
+    JSONReactor(
+        QPDF& pdf, std::shared_ptr<InputSource> is, bool must_be_complete) :
+        pdf(pdf),
+        is(is),
+        must_be_complete(must_be_complete),
+        descr(std::make_shared<QPDFValue::Description>(QPDFValue::JSON_Descr(
+            std::make_shared<std::string>(is->getName()), "")))
+    {
+        for (auto& oc: pdf.m->obj_cache) {
+            if (oc.second.object->getTypeCode() == ::ot_reserved) {
+                reserved.insert(oc.first);
+            }
+        }
+    }
+    virtual ~JSONReactor() = default;
+    virtual void dictionaryStart() override;
+    virtual void arrayStart() override;
+    virtual void containerEnd(JSON const& value) override;
+    virtual void topLevelScalar() override;
+    virtual bool
+    dictionaryItem(std::string const& key, JSON const& value) override;
+    virtual bool arrayItem(JSON const& value) override;
+
+    bool anyErrors() const;
+
+  private:
+    enum state_e {
+        st_initial,
+        st_top,
+        st_qpdf,
+        st_qpdf_meta,
+        st_objects,
+        st_trailer,
+        st_object_top,
+        st_stream,
+        st_object,
+        st_ignore,
+    };
+
+    void containerStart();
+    void nestedState(std::string const& key, JSON const& value, state_e);
+    void setObjectDescription(QPDFObjectHandle& oh, JSON const& value);
+    QPDFObjectHandle makeObject(JSON const& value);
+    void error(qpdf_offset_t offset, std::string const& message);
+    void replaceObject(
+        QPDFObjectHandle to_replace,
+        QPDFObjectHandle replacement,
+        JSON const& value);
+
+    QPDF& pdf;
+    std::shared_ptr<InputSource> is;
+    bool must_be_complete{true};
+    std::shared_ptr<QPDFValue::Description> descr;
+    bool errors{false};
+    bool parse_error{false};
+    bool saw_qpdf{false};
+    bool saw_qpdf_meta{false};
+    bool saw_objects{false};
+    bool saw_json_version{false};
+    bool saw_pdf_version{false};
+    bool saw_trailer{false};
+    state_e state{st_initial};
+    state_e next_state{st_top};
+    std::string cur_object;
+    bool saw_value{false};
+    bool saw_stream{false};
+    bool saw_dict{false};
+    bool saw_data{false};
+    bool saw_datafile{false};
+    bool this_stream_needs_data{false};
+    std::vector<state_e> state_stack{st_initial};
+    std::vector<QPDFObjectHandle> object_stack;
+    std::set<QPDFObjGen> reserved;
+};
 
 void
 QPDF::JSONReactor::error(qpdf_offset_t offset, std::string const& msg)
@@ -365,29 +421,19 @@ QPDF::JSONReactor::containerEnd(JSON const& value)
             object_stack.pop_back();
         }
     } else if ((state == st_top) && (from_state == st_qpdf)) {
-        for (auto const& og: this->reserved) {
-            // Handle dangling indirect object references which the
-            // PDF spec says to treat as nulls. It's tempting to make
-            // this an error, but that would be wrong since valid
-            // input files may have these.
-            QTC::TC("qpdf", "QPDF_json non-trivial null reserved");
-            this->pdf.replaceObject(og, QPDFObjectHandle::newNull());
+        // Handle dangling indirect object references which the PDF spec says to
+        // treat as nulls. It's tempting to make this an error, but that would
+        // be wrong since valid input files may have these.
+        for (auto& oc: pdf.m->obj_cache) {
+            if (oc.second.object->getTypeCode() == ::ot_reserved &&
+                reserved.count(oc.first) == 0) {
+                QTC::TC("qpdf", "QPDF_json non-trivial null reserved");
+                pdf.updateCache(oc.first, QPDF_Null::create(), -1, -1);
+            }
         }
-        this->reserved.clear();
     }
 }
 
-QPDFObjectHandle
-QPDF::JSONReactor::reserveObject(int obj, int gen)
-{
-    QPDFObjGen og(obj, gen);
-    auto oh = pdf.reserveObjectIfNotExists(og);
-    if (oh.isReserved()) {
-        this->reserved.insert(og);
-    }
-    return oh;
-}
-
 void
 QPDF::JSONReactor::replaceObject(
     QPDFObjectHandle to_replace,
@@ -395,7 +441,6 @@ QPDF::JSONReactor::replaceObject(
     JSON const& value)
 {
     auto og = to_replace.getObjGen();
-    this->reserved.erase(og);
     this->pdf.replaceObject(og, replacement);
     auto oh = pdf.getObject(og);
     setObjectDescription(oh, value);
@@ -513,7 +558,7 @@ QPDF::JSONReactor::dictionaryItem(std::string const& key, JSON const& value)
             this->cur_object = "trailer";
         } else if (is_obj_key(key, obj, gen)) {
             this->cur_object = key;
-            auto oh = reserveObject(obj, gen);
+            auto oh = pdf.reserveObjectIfNotExists(QPDFObjGen(obj, gen));
             object_stack.push_back(oh);
             nestedState(key, value, st_object_top);
         } else {
@@ -675,12 +720,13 @@ QPDF::JSONReactor::arrayItem(JSON const& value)
 void
 QPDF::JSONReactor::setObjectDescription(QPDFObjectHandle& oh, JSON const& value)
 {
-    std::string description = this->is->getName();
-    if (!this->cur_object.empty()) {
-        description += ", " + this->cur_object;
+    auto j_descr = std::get<QPDFValue::JSON_Descr>(*descr);
+    if (j_descr.object != cur_object) {
+        descr = std::make_shared<QPDFValue::Description>(
+            QPDFValue::JSON_Descr(j_descr.input, cur_object));
     }
-    description += " at offset " + std::to_string(value.getStart());
-    oh.setObjectDescription(&this->pdf, description);
+
+    oh.getObjectPtr()->setDescription(&pdf, descr, value.getStart());
 }
 
 QPDFObjectHandle
@@ -711,7 +757,7 @@ QPDF::JSONReactor::makeObject(JSON const& value)
         int gen = 0;
         std::string str;
         if (is_indirect_object(str_v, obj, gen)) {
-            result = reserveObject(obj, gen);
+            result = pdf.reserveObjectIfNotExists(QPDFObjGen(obj, gen));
         } else if (is_unicode_string(str_v, str)) {
             result = QPDFObjectHandle::newUnicodeString(str);
         } else if (is_binary_string(str_v, str)) {
