@@ -1,38 +1,45 @@
 #include <qpdf/QTC.hh>
 
+#include <qpdf/QUtil.hh>
+#include <map>
 #include <set>
 #include <stdio.h>
-#include <qpdf/QUtil.hh>
 
-static bool tc_active(char const* const scope)
+static bool
+tc_active(char const* const scope)
 {
     std::string value;
     return (QUtil::get_env("TC_SCOPE", &value) && (value == scope));
 }
 
-void QTC::TC(char const* const scope, char const* const ccase, int n)
+void
+QTC::TC_real(char const* const scope, char const* const ccase, int n)
 {
-    static std::set<std::pair<std::string, int> > cache;
+    static std::map<std::string, bool> active;
+    auto is_active = active.find(scope);
+    if (is_active == active.end()) {
+        active[scope] = tc_active(scope);
+        is_active = active.find(scope);
+    }
 
-    if (! tc_active(scope))
-    {
+    if (!is_active->second) {
         return;
     }
 
+    static std::set<std::pair<std::string, int>> cache;
+
     std::string filename;
 #ifdef _WIN32
 # define TC_ENV "TC_WIN_FILENAME"
 #else
 # define TC_ENV "TC_FILENAME"
 #endif
-    if (! QUtil::get_env(TC_ENV, &filename))
-    {
+    if (!QUtil::get_env(TC_ENV, &filename)) {
         return;
     }
 #undef TC_ENV
 
-    if (cache.count(std::make_pair(ccase, n)))
-    {
+    if (cache.count(std::make_pair(ccase, n))) {
         return;
     }
     cache.insert(std::make_pair(ccase, n));
