@@ -1,20 +1,21 @@
 #include <qpdf/ClosedFileInputSource.hh>
 #include <qpdf/FileInputSource.hh>
 
-#include <stdio.h>
-#include <string.h>
 #include <iostream>
+#include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
-void check(std::string const& what, bool result)
+void
+check(std::string const& what, bool result)
 {
-    if (! result)
-    {
+    if (!result) {
         std::cout << "FAIL: " << what << std::endl;
     }
 }
 
-void do_tests(InputSource* is)
+void
+do_tests(InputSource* is)
 {
     check("get name", "input" == is->getName());
     check("initial tell", 0 == is->tell());
@@ -38,9 +39,9 @@ void do_tests(InputSource* is)
     is->seek(521, SEEK_SET);
     is->read(b, 1);
 #else
-    is->unreadCh('Q');
+    is->unreadCh('\n');
     check("read unread character", 1 == is->read(b, 1));
-    check("got character", 'Q' == b[0]);
+    check("got character", '\n' == b[0]);
 #endif
     check("last offset after read unread", 521 == is->getLastOffset());
     is->seek(0, SEEK_END);
@@ -59,7 +60,8 @@ void do_tests(InputSource* is)
     check("last offset after read 0", 0 == is->getLastOffset());
 }
 
-int main()
+int
+main()
 {
     // This test is designed to work with a specified input file.
     std::cout << "testing with ClosedFileInputSource\n";
@@ -71,8 +73,7 @@ int main()
     do_tests(&cf2);
     cf2.stayOpen(false);
     std::cout << "testing with FileInputSource\n";
-    FileInputSource f;
-    f.setFilename("input");
+    FileInputSource f("input");
     do_tests(&f);
     std::cout << "all assertions passed" << std::endl;
     return 0;
