@@ -1,22 +1,20 @@
+#include <qpdf/assert_test.h>
+
+#include <qpdf/Pl_Buffer.hh>
 #include <qpdf/Pl_Concatenate.hh>
 #include <qpdf/Pl_Flate.hh>
-#include <qpdf/Pl_Buffer.hh>
 #include <qpdf/QUtil.hh>
 #include <iostream>
 
-#ifdef NDEBUG
-// We need assert even in a release build for test code.
-# undef NDEBUG
-#endif
-#include <cassert>
-
-static void pipeStringAndFinish(Pipeline* p, std::string const& str)
+static void
+pipeStringAndFinish(Pipeline* p, std::string const& str)
 {
     p->write(QUtil::unsigned_char_pointer(str), str.length());
     p->finish();
 }
 
-int main(int argc, char* argv[])
+int
+main(int argc, char* argv[])
 {
     Pl_Buffer b1("compressed");
     Pl_Flate deflate("compress", &b1, Pl_Flate::a_deflate);
@@ -31,14 +29,11 @@ int main(int argc, char* argv[])
     inflate.write(b1_buf->getBuffer(), b1_buf->getSize());
     inflate.finish();
     auto b2_buf = b2.getBufferSharedPointer();
-    std::string result(reinterpret_cast<char*>(b2_buf->getBuffer()),
-                       b2_buf->getSize());
-    if (result == "-one--two-")
-    {
+    std::string result(
+        reinterpret_cast<char*>(b2_buf->getBuffer()), b2_buf->getSize());
+    if (result == "-one--two-") {
         std::cout << "concatenate test passed" << std::endl;
-    }
-    else
-    {
+    } else {
         std::cout << "concatenate test failed: " << result << std::endl;
     }
     return 0;
