@@ -4,33 +4,27 @@
 #include <iostream>
 #include <stdlib.h>
 
-int main()
+int
+main()
 {
     Pl_StdioFile out("stdout", stdout);
     Pl_ASCIIHexDecoder decode("decode", &out);
 
-    try
-    {
+    try {
         unsigned char buf[10000];
         bool done = false;
-        while (! done)
-        {
+        while (!done) {
             size_t len = fread(buf, 1, sizeof(buf), stdin);
-            if (len <= 0)
-            {
+            if (len <= 0) {
                 done = true;
-            }
-            else
-            {
+            } else {
                 decode.write(buf, len);
             }
         }
         decode.finish();
-    }
-    catch (std::exception& e)
-    {
+    } catch (std::exception& e) {
         std::cerr << e.what() << std::endl;
-         exit(2);
+        exit(2);
     }
 
     return 0;
