@@ -1,39 +1,39 @@
+#include <qpdf/assert_test.h>
+
 #include <qpdf/JSON.hh>
+#include <qpdf/Pipeline.hh>
+#include <qpdf/QPDF.hh>
 #include <qpdf/QPDFObjectHandle.hh>
 #include <iostream>
 
-#ifdef NDEBUG
-// We need assert even in a release build for test code.
-# undef NDEBUG
-#endif
-#include <cassert>
-
-static void check(JSON const& j, std::string const& exp)
+static void
+check(JSON const& j, std::string const& exp)
 {
-    if (exp != j.unparse())
-    {
+    if (exp != j.unparse()) {
         std::cout << "Got " << j.unparse() << "; wanted " << exp << "\n";
     }
 }
 
-static void test_main()
+static void
+test_main()
 {
     JSON jstr = JSON::makeString(
         "<1>\xcf\x80<2>\xf0\x9f\xa5\x94\\\"<3>\x03\t\b\r\n<4>");
-    check(jstr,
-          "\"<1>\xcf\x80<2>\xf0\x9f\xa5\x94\\\\\\\"<3>"
-          "\\u0003\\t\\b\\r\\n<4>\"");
+    check(
+        jstr,
+        "\"<1>\xcf\x80<2>\xf0\x9f\xa5\x94\\\\\\\"<3>"
+        "\\u0003\\t\\b\\r\\n<4>\"");
     JSON jnull = JSON::makeNull();
     check(jnull, "null");
     assert(jnull.isNull());
     std::string value;
-    assert(! jnull.getNumber(value));
+    assert(!jnull.getNumber(value));
     JSON jarr = JSON::makeArray();
     check(jarr, "[]");
     JSON jstr2 = JSON::makeString("a\tb");
     assert(jstr2.getString(value));
     assert(value == "a\tb");
-    assert(! jstr2.getNumber(value));
+    assert(!jstr2.getNumber(value));
     /* cSpell: ignore jbool xavalue dvalue xdvalue */
     JSON jint = JSON::makeInt(16059);
     JSON jdouble = JSON::makeReal(3.14159);
@@ -44,24 +44,24 @@ static void test_main()
     assert(jbool1.getBool(bvalue));
     assert(bvalue);
     assert(jbool2.getBool(bvalue));
-    assert(! bvalue);
+    assert(!bvalue);
     jarr.addArrayElement(jstr2);
     jarr.addArrayElement(jnull);
     jarr.addArrayElement(jint);
     jarr.addArrayElement(jdouble);
     jarr.addArrayElement(jexp);
-    check(jarr,
-          "[\n"
-          "  \"a\\tb\",\n"
-          "  null,\n"
-          "  16059,\n"
-          "  3.14159,\n"
-          "  2.1e5\n"
-          "]");
+    check(
+        jarr,
+        "[\n"
+        "  \"a\\tb\",\n"
+        "  null,\n"
+        "  16059,\n"
+        "  3.14159,\n"
+        "  2.1e5\n"
+        "]");
     std::vector<std::string> avalue;
-    assert(jarr.forEachArrayItem([&avalue](JSON j) {
-        avalue.push_back(j.unparse());
-    }));
+    assert(jarr.forEachArrayItem(
+        [&avalue](JSON j) { avalue.push_back(j.unparse()); }));
     std::vector<std::string> xavalue = {
         "\"a\\tb\"",
         "null",
@@ -79,60 +79,78 @@ static void test_main()
     jmap.addDictionaryMember("no", JSON::makeBool(true));
     jmap.addDictionaryMember("empty_dict", JSON::makeDictionary());
     jmap.addDictionaryMember("empty_list", JSON::makeArray());
-    jmap.addDictionaryMember("single", JSON::makeArray()).
-        addArrayElement(JSON::makeInt(12));
-    check(jmap,
-          "{\n"
-          "  \"a\": [\n"
-          "    \"a\\tb\",\n"
-          "    null,\n"
-          "    16059,\n"
-          "    3.14159,\n"
-          "    2.1e5\n"
-          "  ],\n"
-          "  \"b\": \"a\\tb\",\n"
-          "  \"c\\r\\nd\": null,\n"
-          "  \"empty_dict\": {},\n"
-          "  \"empty_list\": [],\n"
-          "  \"no\": true,\n"
-          "  \"single\": [\n"
-          "    12\n"
-          "  ],\n"
-          "  \"yes\": false\n"
-          "}");
-    check(QPDFObjectHandle::newReal("0.12").getJSON(), "0.12");
-    check(QPDFObjectHandle::newReal(".34").getJSON(), "0.34");
-    check(QPDFObjectHandle::newReal("-0.56").getJSON(), "-0.56");
-    check(QPDFObjectHandle::newReal("-.78").getJSON(), "-0.78");
+    jmap.addDictionaryMember("single", JSON::makeArray())
+        .addArrayElement(JSON::makeInt(12));
+    check(
+        jmap,
+        "{\n"
+        "  \"a\": [\n"
+        "    \"a\\tb\",\n"
+        "    null,\n"
+        "    16059,\n"
+        "    3.14159,\n"
+        "    2.1e5\n"
+        "  ],\n"
+        "  \"b\": \"a\\tb\",\n"
+        "  \"c\\r\\nd\": null,\n"
+        "  \"empty_dict\": {},\n"
+        "  \"empty_list\": [],\n"
+        "  \"no\": true,\n"
+        "  \"single\": [\n"
+        "    12\n"
+        "  ],\n"
+        "  \"yes\": false\n"
+        "}");
+    for (int i = 1; i <= JSON::LATEST; ++i) {
+        check(QPDFObjectHandle::newReal("0.12").getJSON(i), "0.12");
+        check(QPDFObjectHandle::newReal(".34").getJSON(i), "0.34");
+        check(QPDFObjectHandle::newReal("-0.56").getJSON(i), "-0.56");
+        check(QPDFObjectHandle::newReal("-.78").getJSON(i), "-0.78");
+    }
     JSON jmap2 = JSON::parse(R"({"a": 1, "b": "two", "c": [true]})");
     std::map<std::string, std::string> dvalue;
-    assert(jmap2.forEachDictItem([&dvalue]
-                                 (std::string const& k, JSON j) {
-        dvalue[k] = j.unparse();
-    }));
+    assert(jmap2.forEachDictItem(
+        [&dvalue](std::string const& k, JSON j) { dvalue[k] = j.unparse(); }));
     std::map<std::string, std::string> xdvalue = {
         {"a", "1"},
         {"b", "\"two\""},
         {"c", "[\n  true\n]"},
     };
     assert(dvalue == xdvalue);
+    auto blob_data = [](Pipeline* p) {
+        *p << "\x01\x02\x03\x04\x05\xff\xfe\xfd\xfc\xfb";
+    };
+    JSON jblob = JSON::makeDictionary();
+    jblob.addDictionaryMember("normal", JSON::parse(R"("string")"));
+    jblob.addDictionaryMember("blob", JSON::makeBlob(blob_data));
+    // cSpell:ignore AQIDBAX
+    check(
+        jblob,
+        "{\n"
+        "  \"blob\": \"AQIDBAX//v38+w==\",\n"
+        "  \"normal\": \"string\"\n"
+        "}");
 }
 
-static void check_schema(JSON& obj, JSON& schema, unsigned long flags,
-                         bool exp, std::string const& description)
+static void
+check_schema(
+    JSON& obj,
+    JSON& schema,
+    unsigned long flags,
+    bool exp,
+    std::string const& description)
 {
     std::list<std::string> errors;
     std::cout << "--- " << description << std::endl;
     assert(exp == obj.checkSchema(schema, flags, errors));
-    for (std::list<std::string>::iterator iter = errors.begin();
-         iter != errors.end(); ++iter)
-    {
-        std::cout << *iter << std::endl;
+    for (auto const& error: errors) {
+        std::cout << error << std::endl;
     }
     std::cout << "---" << std::endl;
 }
 
-static void test_schema()
+static void
+test_schema()
 {
     /* cSpell: ignore ptional ebra */
     JSON schema = JSON::parse(R"(
@@ -144,7 +162,9 @@ static void test_schema()
         "x": "ecks"
       },
       "s": [
-        "esses"
+        {
+          "ss": "esses"
+        }
       ]
     }
   },
@@ -159,7 +179,11 @@ static void test_schema()
       "z": "ebra",
       "o": "ptional"
     }
-  }
+  },
+  "four": [
+    { "first": "first element" },
+    { "second": "second element" }
+  ]
 }
 )");
 
@@ -207,17 +231,30 @@ static void test_schema()
     "else": {
       "z": "okay"
     }
-  }
+  },
+  "four": [
+    {"first": "missing second"}
+  ]
 }
 )");
 
     check_schema(b, schema, 0, false, "missing items");
-    check_schema(a, a, 0, false, "top-level schema array error");
-    check_schema(b, b, 0, false, "lower-level schema array error");
 
     JSON bad_schema = JSON::parse(R"({"a": true, "b": "potato?"})");
     check_schema(bad_schema, bad_schema, 0, false, "bad schema field type");
 
+    JSON c = JSON::parse(R"(
+{
+  "four": [
+    { "first": 1 },
+    { "oops": [2] }
+  ]
+}
+)");
+    check_schema(c, schema, JSON::f_optional, false, "array element mismatch");
+
+    // "two" exercises the case of the JSON containing a single
+    // element where the schema has an array.
     JSON good = JSON::parse(R"(
 {
   "one": {
@@ -227,32 +264,36 @@ static void test_schema()
         "x": [1, null]
       },
       "s": [
-        null,
-        "anything"
+        {"ss": null},
+        {"ss": "anything"}
       ]
     }
   },
-  "two": [
-    {
-      "glarp": "enspliel",
-      "goose": 3.14
-    }
-  ],
+  "two": {
+    "glarp": "enspliel",
+    "goose": 3.14
+  },
   "three": {
     "<objid>": {
       "z": "ebra"
     }
-  }
+  },
+  "four": [
+    { "first": 1 },
+    { "second": [2] }
+  ]
 }
 )");
     check_schema(good, schema, 0, false, "not optional");
     check_schema(good, schema, JSON::f_optional, true, "pass");
 }
 
-int main()
+int
+main()
 {
     test_main();
     test_schema();
+    assert(QPDF::test_json_validators());
 
     std::cout << "end of json tests\n";
     return 0;
